@@ -1,5 +1,5 @@
 /* See http://www.python-ldap.org/ for details.
- * $Id: options.c,v 1.39 2011/06/10 21:55:45 stroeder Exp $ */
+ * $Id: options.c,v 1.41 2013/09/11 08:16:27 stroeder Exp $ */
 
 #include "common.h"
 #include "errors.h"
@@ -291,6 +291,12 @@ LDAP_get_option(LDAPObject *self, int option)
 #ifdef LDAP_OPT_X_TLS_CRLFILE
     case LDAP_OPT_X_TLS_CRLFILE:
 #endif
+#ifdef LDAP_OPT_X_TLS_VERSION
+    case LDAP_OPT_X_TLS_VERSION:
+#endif
+#ifdef LDAP_OPT_X_TLS_CIPHER
+    case LDAP_OPT_X_TLS_CIPHER:
+#endif
 #ifdef LDAP_OPT_X_TLS_PACKAGE
     case LDAP_OPT_X_TLS_PACKAGE:
 #endif
